Commit Diff


commit - 11ff7f934e2bb3920b900327c5fb38d30691c2ca
commit + 5d38e5d88d423a7a84f714841cc161829f236b13
blob - a1b3f7ebfd2a8fed5077114759a603b620a78ea6
blob + df677b41412bcaf9c01026464e363d1eac669214
--- titan.c
+++ titan.c
@@ -279,15 +279,15 @@ main(int argc, char **argv)
 	if (fstat(fileno(in), &sb) == -1)
 		err(1, "fstat");
 
 	/* prepare the URL */
 	if (strlcpy(iribuf, argv[0], sizeof(iribuf)) >= sizeof(iribuf))
-		errx(1, "URL too long");
+		errx(1, "IRI too long");
 
 	if (!parse_iri(iribuf, &iri, &errstr))
 		errx(1, "invalid IRI: %s", errstr);
 
 	if (strcmp(iri.schema, "titan") != 0)
-		errx(1, "not a titan:// URI");
+		errx(1, "not a titan:// IRI");
 
 	if (token && mime) {
 		if (asprintf(&path, "%s;size=%lld;token=%s;mime=%s", iri.path,
@@ -310,7 +310,7 @@ main(int argc, char **argv)
 	iri.path = path;
 	if (!serialize_iri(&iri, reqbuf, sizeof(reqbuf)) ||
 	    strlcat(reqbuf, "\r\n", sizeof(reqbuf)) >= sizeof(reqbuf))
-		errx(1, "URI too long");
+		errx(1, "IRI too long");
 
 	if ((config = tls_config_new()) == NULL)
 		err(1, "tls_config_new");
@@ -279,15 +279,15 @@ main(int argc, char **argv)
 		err(1, "fstat");
 
-	/* prepare the URL */
+	/* prepare the IRI */
 	if (strlcpy(iribuf, argv[0], sizeof(iribuf)) >= sizeof(iribuf))